/*
 * cmduqueue.h
 * implments CMDU queue.
 *
 * Copyright (C) 2021 IOPSYS Software Solutions AB. All rights reserved.
 *
 * Author: anjan.chanda@iopsys.eu
 *
 * See LICENSE file for license related information.
 *
 */

#ifndef CMDUQUEUE_H
#define CMDUQUEUE_H

#include <stdint.h>
#include <pthread.h>
#include <sys/time.h>
#include <libubox/list.h>

#include <easy/easy.h>



/** struct cmdu_queue - queue to hold CMDU buffers */
struct cmdu_queue {
	struct list_head q;
	pthread_mutex_t lock;
	pthread_cond_t empty;
};

extern int cmdu_queue_init(struct cmdu_queue *q);
extern int cmdu_queue_destroy(struct cmdu_queue *q);
extern void cmdu_queue_flush(struct cmdu_queue *q);
extern void cmdu_queue_wait(struct cmdu_queue *q);
extern void cmdu_queue_signal(struct cmdu_queue *q);
extern void cmdu_enqueue(struct cmdu_queue *q, struct cmdu_buff *c);
extern struct cmdu_buff *cmdu_dequeue(struct cmdu_queue *q);


#endif /* CMDUQUEUE_H */
